<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="zh_CN">
<context>
    <name>@default</name>
    <message>
        <location filename="../src/main.cpp" line="82"/>
        <source>File does not exist</source>
        <translation type="obsolete">文件不存在</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="86"/>
        <source>The file %1 could not be found. Please check this and try again.</source>
        <translation type="obsolete">文件 %1 未找到。请检查并重试。</translation>
    </message>
</context>
<context>
    <name>@default</name>
    <message>
        <location filename="../src/main.cpp" line="82"/>
        <source>File does not exist</source>
        <translation type="unfinished">文件不存在</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="86"/>
        <source>The file %1 could not be found. Please check this and try again.</source>
        <translation type="unfinished">文件 %1 未找到。请检查并重试。</translation>
    </message>
</context>
<context>
    <name>QDialog</name>
    <message>
        <location filename="" line="134997500"/>
        <source>Program Files</source>
        <translation type="obsolete">程序文件</translation>
    </message>
</context>
<context>
    <name>pageFinished</name>
    <message>
        <location filename="../dialogs/page_setup_finished.ui" line="43"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;iTALC is now installed!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;现在安装 iTALC !&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_setup_finished.ui" line="61"/>
        <source>iTALC is now completely installed. If you installed the master application you can start it using the start-menu.</source>
        <translation>iTALC 安装完成。如果你安装了主应用程序，你可以自开始菜单中启动它。</translation>
    </message>
    <message>
        <location filename="../dialogs/page_setup_finished.ui" line="71"/>
        <source>Save installation settings</source>
        <translation>保存安装设置</translation>
    </message>
</context>
<context>
    <name>pageInstallDir</name>
    <message>
        <location filename="../dialogs/page_install_dir.ui" line="37"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Choose installation directory&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;选择安装目录&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_install_dir.ui" line="47"/>
        <source>Please choose the directory in which iTALC is going to be installed. It&apos;s recommended to leave the default-directory, but it&apos;s no problem to change it.</source>
        <translation>请选择将要安装 iTALC 的目录。推荐使用默认目录，但改变它也没有问题。</translation>
    </message>
</context>
<context>
    <name>pageKeyDirs</name>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="37"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Directories for keys&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;密钥目录&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="47"/>
        <source>The newly created or imported key(s) need to be installed somewhere. It&apos;s recommended to leave the suggested directories.</source>
        <translation>新创建或导入的密钥所需的安装目录。推荐使用建议的目录。</translation>
    </message>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="73"/>
        <source>Directory to store public key in</source>
        <translation>存储公共密钥目录</translation>
    </message>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="147"/>
        <source>Directory to store private key in</source>
        <translation>存储私有密钥目录</translation>
    </message>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="212"/>
        <source>You can choose a directory in which to export the public key, e.g. a USB-drive or a network share.</source>
        <translation>你可以选择一个目录用来导出公共密钥，例如，USB盘或网络共享文件夹。</translation>
    </message>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="258"/>
        <source>Export private key too</source>
        <translation>导出私有密钥</translation>
    </message>
</context>
<context>
    <name>pageLicenseAgreement</name>
    <message>
        <location filename="../dialogs/page_license_agreement.ui" line="40"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;License agreement&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;许可协议&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_license_agreement.ui" line="50"/>
        <source>iTALC is published under the terms of the General Public License (GPL). Please read the following license terms and choose whether you agree or disagree the license.</source>
        <translation>iTALC 在 General Public License (GPL) 协议下发行。请阅读以下许可条款并选择是否同意或拒绝该许可。</translation>
    </message>
    <message>
        <location filename="../dialogs/page_license_agreement.ui" line="81"/>
        <source>I agree</source>
        <translation>我同意</translation>
    </message>
    <message>
        <location filename="../dialogs/page_license_agreement.ui" line="88"/>
        <source>I disagree</source>
        <translation>我拒绝</translation>
    </message>
</context>
<context>
    <name>pageSecurityOptions</name>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="53"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Security options&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;安全选项&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="63"/>
        <source>iTALC has a sophisticated security-concept for preventing unauthorized access to computers having iTALC client software installed. Therefore you either have to create a new key-pair or import the public key created during iTALC installation on master computer.</source>
        <translation>iTALC 具有尖端的安全概念阻止对安装了 iTALC 客户端的计算机的非法的访问。因此你要创建新的密钥对或导入由 iTALC 主计算机创建的公共密钥。</translation>
    </message>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="73"/>
        <source>Create a new key-pair (only do that on master computer)</source>
        <translation>创建新密钥对 (只在主计算机上进行)</translation>
    </message>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="80"/>
        <source>Import public key of master computer</source>
        <translation>导入主计算机的公共密钥</translation>
    </message>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="114"/>
        <source>Choose location of exported public key:</source>
        <translation>选择导出公共密钥的位置:</translation>
    </message>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="152"/>
        <source>Keep all keys (only when updating existing installation!)</source>
        <translation>保持全部密钥 (只在升级时使用)</translation>
    </message>
</context>
<context>
    <name>pageSelectComponents</name>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="37"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Select components to install&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;选择要安装的组件&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="55"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Now it&apos;s time to choose which components of iTALC you want to install on this computer. If this is a client-computer you should only install the client-software.&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600; font-style:italic;&quot;&gt;Please note, that the master application depends the client-software in order to function properly.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;选择你要安装的组件。如果这是个客户端计算机你应该只选择安装客户端软件。&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600; font-style:italic;&quot;&gt;Please note, that the master application depends the client-software in order to function properly.请注意，主应用程序需要同时安装客户端软件。&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="70"/>
        <source>Components</source>
        <translation>组件</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="93"/>
        <source>iTALC Client Appliction (ICA)</source>
        <translation>iTALC 客户端软件(ICA)</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="103"/>
        <source>iTALC Master Application (IMA)</source>
        <translation>iTALC 主应用程序(IMA)</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="113"/>
        <source>Online-Update Service (LUPUS)</source>
        <translation>在线升级服务(LUPUS)</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="123"/>
        <source>iTALC documentation</source>
        <translation>iTALC 文档</translation>
    </message>
</context>
<context>
    <name>pageWelcome</name>
    <message>
        <location filename="../dialogs/page_welcome.ui" line="43"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Welcome to installation of iTALC&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;欢迎进入 iTALC 安装&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_welcome.ui" line="61"/>
        <source>This setup-wizard will guide you through the installation of iTALC on this computer. The installation includes the client-software as well as the optional master-application.

Furthermore you&apos;ll be able to setup security-settings.

Click &apos;Next&apos; to continue.</source>
        <translation>安装向导将引导你把 iTALC 安装到计算机。这个安装包括客户端软件和可选的主应用程序。

此外你将安装安全设置。

点击‘下一步’继续。</translation>
    </message>
</context>
<context>
    <name>setupWizard</name>
    <message>
        <location filename="../src/dialogs.cpp" line="155"/>
        <source>Confirm overwrite</source>
        <translation>覆盖确认</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="156"/>
        <source>Do you want to overwrite %1?</source>
        <translation>你确定要覆盖吗?</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="212"/>
        <source>Installing iTALC</source>
        <translation>正在安装 iTALC</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="214"/>
        <source>Copying files...</source>
        <translation>复制文件...</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="279"/>
        <source>Registering ICA as service...</source>
        <translation>注册 ICA 服务...</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="322"/>
        <source>Creating/importing keys...</source>
        <translation>创建/导入密钥...</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="354"/>
        <source>Creating shortcuts...</source>
        <translation>创建快捷方式...</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="376"/>
        <source>Could not create directory</source>
        <translation>不能创建目录</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="380"/>
        <source>Could not create directory %1! Make sure you have the neccessary rights and try again!</source>
        <translation>不能创建目录 %1 ！确认你拥有必要的权限并重试!</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="393"/>
        <source>Cancel setup</source>
        <translation>取消安装</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="395"/>
        <source>Are you sure want to quit setup? iTALC is not installed completely yet!</source>
        <translation>你确定要退出安装吗？ iTALC 还未安装完成!</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="416"/>
        <source>Next</source>
        <translation>下一步</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="475"/>
        <source>Finish</source>
        <translation>完成</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="481"/>
        <source>Quit</source>
        <translation>退出</translation>
    </message>
</context>
<context>
    <name>setupWizardPageInstallDir</name>
    <message>
        <location filename="../src/dialogs.cpp" line="590"/>
        <source>Directory does not exist</source>
        <translation>目录不存在</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="592"/>
        <source>The specified directory does not exist. Do you want to create it?</source>
        <translation>指定目录不存在。你想要创建它吗?</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="614"/>
        <source>Choose installation directory</source>
        <translation>选择安装目录</translation>
    </message>
</context>
<context>
    <name>setupWizardPageKeyDirs</name>
    <message>
        <location filename="../src/dialogs.cpp" line="848"/>
        <source>Choose public key directory</source>
        <translation>选择公共密钥目录</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="862"/>
        <source>Choose private key directory</source>
        <translation>选择私有密钥目录</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="876"/>
        <source>Choose public key export directory</source>
        <translation>选择公共密钥导出目录</translation>
    </message>
</context>
<context>
    <name>setupWizardPageSecurityOptions</name>
    <message>
        <location filename="../src/dialogs.cpp" line="750"/>
        <source>Choose directory for key-import</source>
        <translation>选择密钥导入目录</translation>
    </message>
</context>
<context>
    <name>wizard</name>
    <message>
        <location filename="../dialogs/wizard.ui" line="21"/>
        <source>iTALC-Setup</source>
        <translation>iTALC 安装</translation>
    </message>
    <message>
        <location filename="../dialogs/wizard.ui" line="67"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../dialogs/wizard.ui" line="77"/>
        <source>Back</source>
        <translation>后退</translation>
    </message>
    <message>
        <location filename="../dialogs/wizard.ui" line="87"/>
        <source>Next</source>
        <translation>下一步</translation>
    </message>
</context>
</TS>
